package envoy.client.ui;

import javafx.scene.control.Label;
import javafx.scene.control.ListCell;
import javafx.scene.layout.VBox;

import envoy.data.Contact;
import envoy.data.Group;
import envoy.data.User;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>UserListCell.java</strong><br>
 * Created: <strong>28.03.2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Client v0.1-beta
 */
public class ContactListCell extends ListCell<Contact> {

	/**
	 * Displays the name of a contact. If the contact is a user, their online status
	 * is displayed as well.
	 *
	 * @since Envoy Client v0.1-beta
	 */
	@Override
	protected void updateItem(Contact contact, boolean empty) {
		super.updateItem(contact, empty);
		if (empty || contact == null) {
			setText(null);
			setGraphic(null);
		} else {
			// Container with contact name
			final var vbox = new VBox(new Label(contact.getName()));
			if (contact instanceof User) {
				// Online status
				final var	user		= (User) contact;
				final var	statusLabel	= new Label(user.getStatus().toString());
				statusLabel.getStyleClass().add(user.getStatus().toString().toLowerCase());
				vbox.getChildren().add(statusLabel);
			} else vbox.getChildren().add(new Label(((Group) contact).getContacts().size() + " members"));
			setGraphic(vbox);
		}
	}
}
